summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--riscos/plugin.c17
-rw-r--r--riscos/plugin.h2
2 files changed, 10 insertions, 9 deletions
diff --git a/riscos/plugin.h b/riscos/plugin.h
index 8c49a264b..916893d19 100644
--- a/riscos/plugin.h
+++ b/riscos/plugin.h
@@ -47,7 +47,7 @@ bool plugin_redraw(struct content *c, int x, int y,
int clip_x0, int clip_y0, int clip_x1, int clip_y1,
float scale, unsigned long background_colour);
void plugin_open(struct content *c, struct browser_window *bw,
- struct content *page, struct box *box,
+ struct content *page, unsigned int index, struct box *box,
struct object_params *params);
void plugin_close(struct content *c);
diff --git a/riscos/plugin.c b/riscos/plugin.c
index ee05c5bf1..8a8b0c921 100644
--- a/riscos/plugin.c
+++ b/riscos/plugin.c
@@ -250,17 +250,18 @@ bool plugin_redraw(struct content *c, int x, int y,
/**
- * Handle a window containing a CONTENT_PLUGIN being opened
+ * Handle a window containing a CONTENT_PLUGIN being opened.
*
* \param c The content to open
* \param bw The window to add the content to
* \param page The containing content
* \param box The containing box
* \param params Any parameters associated with the content
* \param state State data pointer
*/
void plugin_open(struct content *c, struct browser_window *bw,
- struct content *page, struct box *box,
+ struct content *page, unsigned int index, struct box *box,
struct object_params *params)
{
bool standalone = false, helper = false;
@@ -250,17 +250,18 @@ bool plugin_redraw(struct content *c, int x, int y,
*
- * \param c The content to open
- * \param bw The window to add the content to
- * \param page The containing content
- * \param box The containing box
- * \param params Any parameters associated with the content
- * \param state State data pointer
+ * \param c content that has been opened
+ * \param bw browser window containing the content
+ * \param page content of type CONTENT_HTML containing c, or 0 if not an
+ * object within a page
+ * \param index index in page->data.html.object, or 0 if not an object
+ * \param box box containing c, or 0 if not an object
+ * \param params object parameters, or 0 if not an object
*/
void plugin_open(struct content *c, struct browser_window *bw,